import { PlatformManifest } from 'expo-constants';
export interface QuestionDetail {
    leftText: string;
    rightText: string;
}
export interface Question {
    variableName: string;
    engQuestion: QuestionDetail;
    spnQuestion: QuestionDetail;
}
export interface Interview {
    id: string;
    name: string;
    questions: Question[];
}
export interface Answer {
    dateCreated: number;
    index: number;
    response: string;
    variable: string;
}
export declare type Location = string[];
export interface UserAccessInfo {
    enabled: boolean;
    manageUserAccess: boolean;
    viewResults: boolean;
    viewActiveDevices: boolean;
    editInterview: boolean;
    admin: boolean;
}
export interface Result {
    adminResult: AdminResult;
    answers: Answer[];
    assent: boolean;
    dateQuestionsStarted: number;
    dateQuestionsUpdated: number;
    datePracticeStarted: number;
    datePracticeUpdated: number;
    dateSessionStart: number;
    dateUpdated: number;
    childId: string;
    id: string;
    interviewer: string;
    language: string;
    practiceDuration: number;
    questionDuration: number;
    school: string;
    sessionDuration: number;
}
export interface CsvStatus {
    modified: boolean;
    dateUpdated: number;
}
export interface AdminResult {
    break: string;
    childrenOverseen: string;
    collegeGoal: string;
    engaged: string;
    help: string;
    savingMoneyGoal: string;
    incompletenessExplanation: string;
    otherAffects: string;
}
export interface InitializationInfo {
    assent?: boolean;
    childId: string;
    interviewer: string;
    language: string;
    school: string;
}
export interface ConnectedDevice {
    connections: any[];
    info: DeviceInfo;
    lastOnline: number;
    progress: {
        currentQuestion?: number;
        initializationInfo?: InitializationInfo;
        result?: Result;
    };
}
export interface DeviceInfo {
    appOwnership: string | null;
    deviceName: string;
    deviceYearClass: number | null;
    installationId: string;
    isDevice: boolean;
    manifest: any;
    platform: PlatformManifest | {
        OS: 'ios' | 'android' | 'windows' | 'macos' | 'web';
    } | undefined;
    sessionId: string;
}
export declare type UserClaims = {
    [interviewId: string]: boolean;
};
export interface FirebaseUser {
    uid: string;
    email: string;
    emailVerified: boolean;
    displayName: string;
    photoURL: string;
    phoneNumber: undefined;
    disabled: boolean;
    claims: UserClaims;
    metadata: {
        lastSignInTime: string;
        creationTime: string;
    };
    passwordHash: string | undefined;
    passwordSalt: string | undefined;
    customClaims: UserClaims | undefined;
    tokensValidAfterTime: string;
    providerData: [
        {
            uid: string;
            displayName: string;
            email: string;
            photoURL: string;
            providerId: string;
            phoneNumber: string | undefined;
        }
    ];
}
export interface Theme {
    primaryColor: string;
    secondaryColor: string;
    tertiaryColor: string;
    lightText: string;
    greyText: string;
    darkText: string;
    lightBackground: string;
    lightIcon: string;
    disabledBackground: string;
    activeGreen: string;
    activeGreenBackground: string;
    errorBackground: string;
    errorText: string;
    lightRedBackground: string;
    warningBackground: string;
    warningText: string;
}
export declare type AuditVersionRecord = {
    [version: string]: {
        [device: string]: AuditChildRecord;
    };
};
export declare type AuditChildRecord = {
    [childId: string]: {
        actions: AuditAction[];
        initializationInfo: InitializationInfo;
    };
};
export declare type AuditAction = {
    [timestamp: string]: AuditActionDetails;
};
export declare type AuditActionDetails = {
    currentQuestionIndex: number;
    description: string;
    info: {
        currentQuestion: {
            engQuestion: {
                leftText: string;
                rightText: string;
            };
            spnQuestion: {
                leftText: string;
                rightText: string;
            };
            variableName: string;
        };
        currentlyShowingAnimation: boolean;
        previousResponse: string;
        questionIndex: number;
        direction?: 'Left' | 'Right';
        leftText?: string;
        playThatsLikeMe?: boolean;
        questionPosed?: boolean;
        rightText?: string;
        selectedText?: string;
        thatsLikeMeFile?: string;
    };
    timestamp: number;
};
export declare const nullAdminResult: () => AdminResult;
export declare const nullResult: (id?: string | undefined, interviewer?: string | undefined, school?: string | undefined, language?: string | undefined, assent?: boolean | undefined, questions?: string[] | undefined) => Result;
export declare const nullQuestionDetail: () => QuestionDetail;
export declare const nullQuestion: () => Question;
export declare const nullInterview: () => Interview;
export declare const nullAnswer: (index?: number | undefined, variable?: string | undefined) => Answer;
export declare const nullCsvStatus: () => CsvStatus;
